@@ -1,4 +1,5 @@
 import os, datetime, logging
+from logging.handlers import TimedRotatingFileHandler
 from inspect import getframeinfo, stack
 from typing import List, Optional
 import requests, json
@@ -8,18 +9,25 @@ from .do import LogItemDO, LogRecordDO
 
 
 class LocalLogger:
-    def __init__(self, name:Optional[str]=None, log_dir='/tmp/log') -> None:
+    def __init__(self, name:Optional[str]=None, log_dir='/tmp/log', stack_layer=2) -> None:
         if name is None:
             name = 'root'
+        self.stack_layer = stack_layer
         self.logger = logging.getLogger(name)
         self.logger.setLevel(logging.DEBUG)
         if not os.path.exists(log_dir):
             os.makedirs(log_dir)
-        info_file_handler = logging.FileHandler(
-            os.path.join(os.path.join(log_dir, f'{name}_info.log'))
+        info_file_handler = TimedRotatingFileHandler(
+            os.path.join(os.path.join(log_dir, f'{name}_info.log')),
+            when='MIDNIGHT',
+            backupCount=10,
+            encoding='utf-8'
         ) 
-        debug_file_handler = logging.FileHandler(
-            os.path.join(os.path.join(log_dir, f'{name}_debug.log'))
+        debug_file_handler = TimedRotatingFileHandler(
+            os.path.join(os.path.join(log_dir, f'{name}_debug.log')),
+            when='MIDNIGHT',
+            backupCount=10,
+            encoding='utf-8'
         )
         print_handler = logging.StreamHandler()
         info_file_handler.setLevel(logging.INFO)
@@ -40,7 +48,7 @@ class LocalLogger:
 
     def _get_header(self, msg_type:str):
         date = datetime.datetime.utcnow().isoformat()
-        caller = getframeinfo(stack()[2][0])
+        caller = getframeinfo(stack()[self.stack_layer][0])
         line_num = caller.lineno
         fn = caller.filename
         fn = os.path.basename(fn)
@@ -140,7 +148,7 @@ class Logger:
         self.keywords = keywords
         self.controller = LogController(controller_ip, controller_port)
         self.combine_keywords = combine_keywords
-        self.logger = LocalLogger(domain)
+        self.logger = LocalLogger(domain, stack_layer=3)
 
     def _send_record(
         self, 
@@ -184,6 +192,12 @@ class Logger:
         else:
             return False
 
+    def debug(self, msg):
+        self.logger.debug(msg)
+
+    def warning(self, msg):
+        self.logger.warning(msg)
+
     def info(
         self, 
         content, 
